package models

import (
	"encoding/json"
	"fmt"
	"io"
	"net/http"
	"strings"
)

type lastFMTrack struct {
	Name   string `json:"name"`
	Artist struct {
		Name string `json:"#text"`
	} `json:"artist"`
	Album struct {
		Name string `json:"#text"`
	} `json:"album"`
	Date struct {
		Unix string `json:"#text"`
	} `json:"date"`
}

type lastFMResponse struct {
	RecentTracks struct {
		Tracks []lastFMTrack `json:"track"`
	} `json:"recenttracks"`
}

func lastFMGetRecentTracks(username, apiKey string) (*lastFMResponse, error) {
	url := fmt.Sprintf("https://ws.audioscrobbler.com/2.0/?method=user.getrecenttracks&user=%s&api_key=%s&format=json", username, apiKey)
	resp, err := http.Get(url)
	if err != nil {
		return nil, fmt.Errorf("lastfm get resp err: %v", err)
	}
	defer resp.Body.Close()
	body, err := io.ReadAll(resp.Body)
	if err != nil {
		return nil, fmt.Errorf("lastfm read resp body err: %v", err)
	}
	var lastFMResponse lastFMResponse
	if err := json.Unmarshal(body, &lastFMResponse); err != nil {
		return nil, fmt.Errorf("lastfm unmarshal err: %v", err)
	}

	return &lastFMResponse, nil
}

func LastFMGetLastTrack(username, apiKey string) (string, error) {
	resp, err := lastFMGetRecentTracks(username, apiKey)
	if err != nil {
		return "", err
	}
	var data string
	if len(resp.RecentTracks.Tracks) > 0 {
		track := resp.RecentTracks.Tracks[0]
		data = fmt.Sprintf("%s - %s", track.Name, track.Artist.Name)
		data = strings.ReplaceAll(data, "🅴", "[E]")
	} else {
		return "", fmt.Errorf("len(resp.RecentTracks.Tracks) <= 0")
	}
	return data, nil
}
