package tools

import (
	"bufio"
	"fmt"
	"log"
	"os"
	"strings"
	"time"
)

func SetupLogging(logFilePath string) (*os.File, error) {

	// Проверяем размер файла
	var append = true
	if fi, err := os.Stat(logFilePath); err == nil {
		if fi.Size() > 10*1024*1024 { // 10 МБ
			append = false
		}
	}

	// Логи дописываются в файл если он меньше 10 МБ, иначе
	// файл перезаписывается
	var flags int
	if append {
		flags = os.O_CREATE | os.O_WRONLY | os.O_APPEND
	} else {
		flags = os.O_CREATE | os.O_WRONLY | os.O_TRUNC
	}

	file, err := os.OpenFile(logFilePath, flags, 0666)
	if err != nil {
		return nil, err
	}

	log.SetOutput(file)
	return file, nil
}

func GetLogFileEntriesCount(logFilePath, grepPattern string, hoursAgo int) (int, error) {
	// Если файл не существует - ошибка
	if _, err := os.Stat(logFilePath); os.IsNotExist(err) {
		return 0, fmt.Errorf("log file not found: %s", logFilePath)
	}

	// Открывает файл для чтения
	file, err := os.Open(logFilePath)
	if err != nil {
		return 0, fmt.Errorf("failed to open log file: %v", err)
	}
	defer file.Close()

	// Вычисляется временная граница (текущее время - hoursAgo)
	timeThreshold := time.Now().Add(-time.Duration(hoursAgo) * time.Hour)
	count := 0

	scanner := bufio.NewScanner(file)
	for scanner.Scan() {
		line := scanner.Text()

		// Парсим дату из строки (формат "2006/01/02 15:04:05")
		if len(line) < 20 { // Минимальная длина для даты
			continue
		}
		logTime, err := time.Parse("2006/01/02 15:04:05", line[:19])
		if err != nil {
			continue // Пропускаются строки где не дата
		}

		// Проверка попадает ли дана во временной интервал
		if logTime.After(timeThreshold) && strings.Contains(line, grepPattern) {
			count++
		}
	}

	if err := scanner.Err(); err != nil {
		return 0, fmt.Errorf("error reading log file: %v", err)
	}

	return count, nil
}
